require 'test_helper'
require 'byebug'

module Wild
  # Testing Wild::RemoteRendererTest
  class RemoteRendererTest < Minitest::Test
    def setup
      Wild::Views.root = Pathname.new 'test/fixtures-remote/views'
      Wild::Views.config = { 'endpoint' => 'http://myendpoint.com' }
    end

    def teardown
      FileUtils.rm_rf Wild::Views.root.parent
    end

    def lookup_context
      @lookup_context ||= begin
        ActionView::LookupContext.new ['test/fixtures/views', Wild::Views.root]
      end
    end

    def view
      OpenStruct.new lookup_context: lookup_context
    end

    def test_render_normal_partial
      renderer = ActionView::Renderer.new lookup_context
      locals = { name: 'test' }

      result = renderer.render view, partial: 'partial_test', locals: locals
      assert_equal result, "Hello test\n"
    end

    def test_render_partial_from_remote_server
      stub_request(:get, 'http://myendpoint.com/partial_remote')
        .to_return(status: 200,
                   body: 'Hello <%= name %> from remote server'
                  )

      renderer = ActionView::Renderer.new lookup_context
      locals = { name: 'test' }

      result = renderer.render view, partial: 'partial_remote',
                                     remote: true,
                                     locals: locals
      assert_equal result, 'Hello test from remote server'
    end
  end
end
